%bcond_without  doc
%bcond_without  linuxgpio
%bcond_without  linuxspi
%bcond_without  parport
%bcond_with     sharedlibs

Name:           avrdude
Version:        8.0
Release:        %mkrel 2
Summary:        Software for programming Atmel AVR Microcontroller
Group:          Development/Tools
License:        GPLv2+
URL:            https://www.nongnu.org/avrdude
Source0:        https://github.com/avrdudes/avrdude/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        avrdude-udev-rules
BuildRequires:  cmake
BuildRequires:  ninja
BuildRequires:  flex
BuildRequires:  bison
BuildRequires:  glibc-devel
BuildRequires:  pkgconfig(readline)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(hidapi-hidraw)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libftdi1)
BuildRequires:  pkgconfig(libserialport)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  swig
BuildRequires:  perl
BuildRequires:  texi2html
BuildRequires:  texinfo-tex
# TODO
#BuildRequires:  pkgconfig(libgpiod)
# Fix for MGA#14513 - post scriptlet failed without systemd.
Requires(post):   systemd
Requires(postun): systemd

%define udev_rules 70-avrdude_usbprog.rules

%description
AVRDUDE is a program for programming Atmel's AVR CPU's. It can program
the Flash and EEPROM, and where supported by the serial programming
protocol, it can program fuse and lock bits. AVRDUDE also supplies a
direct instruction mode allowing one to issue any programming
instruction to the AVR chip regardless of whether AVRDUDE implements
that specific feature of a particular chip.

%prep
%autosetup -p1

%build
%cmake \
	-DBUILD_DOC:BOOL=%{?with_doc:ON}%{!?with_doc:OFF} \
	-DBUILD_SHARED_LIBS:BOOL=%{?with_sharedlibs:ON}%{!?with_sharedlibs:OFF} \
	-DHAVE_LINUXGPIO:BOOL=%{?with_linuxgpio:ON}%{!?with_linuxgpio:OFF} \
	-DHAVE_LINUXSPI:BOOL=%{?with_linuxspi:ON}%{!?with_linuxspi:OFF} \
	-DHAVE_PARPORT:BOOL=%{?with_parport:ON}%{!?with_parport:OFF} \
	-DUSE_EXTERNAL_LIBS:BOOL=OFF \
	-GNinja
%cmake_build

%install
%cmake_install

# remove sharedlibs, if not needed
%if %{without sharedlibs}
rm -fr %{buildroot}%{_includedir}
rm -fr %{buildroot}%{_libdir}
%endif

install -d -m 755 %{buildroot}%{_udevrulesdir}
install -m 644 %{SOURCE1} %{buildroot}%{_udevrulesdir}/%{udev_rules}

%post
udevadm control --reload

%postun
udevadm control --reload


%files
%license COPYING
%doc %{_docdir}/%{name}/
%config(noreplace) %{_sysconfdir}/avrdude.conf
%{_bindir}/%{name}
%{_bindir}/%{name}-gui
%{_bindir}/elf2tag
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}.1*
%{_infodir}/%{name}.info*
%{_udevrulesdir}/%{udev_rules}


%changelog
* Tue Jul 01 2025 umeabot <umeabot> 8.0-2.mga10
+ Revision: 2233710
- Mageia 10 Mass Rebuild

* Wed Jan 08 2025 daviddavid <daviddavid> 8.0-1.mga10
+ Revision: 2136289
- new version: 8.0
- enable libserialport, libelf, hidapi and libftdi1 support
- move config file from /etc/avrdude/avrdude.conf to /etc/avrdude.conf
- switch to libusb-1.0

* Sat Feb 10 2024 daviddavid <daviddavid> 7.3-1.mga10
+ Revision: 2040129
- new version: 7.3
- switch to cmake build system
- new Url now at https://github.com/avrdudes/avrdude

* Fri Aug 12 2022 neoclust <neoclust> 7.0-1.mga9
+ Revision: 1877160
- New version 7.0

* Fri Mar 25 2022 umeabot <umeabot> 6.3-7.mga9
+ Revision: 1826438
- Mageia 9 Mass Rebuild

* Tue Feb 18 2020 umeabot <umeabot> 6.3-6.mga8
+ Revision: 1542023
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Jan 04 2020 luigiwalser <luigiwalser> 6.3-5.mga8
+ Revision: 1475932
- rebuild for readline
+ wally <wally>
- replace deprecated %%makeinstall_std

* Fri Sep 21 2018 umeabot <umeabot> 6.3-4.mga7
+ Revision: 1295208
- Mageia 7 Mass Rebuild

* Mon Sep 03 2018 tv <tv> 6.3-3.mga7
+ Revision: 1256806
- rely on filetriggers for info system (mga#23482)

* Tue Jan 02 2018 wally <wally> 6.3-2.mga7
+ Revision: 1189415
- rebuild for new readline

* Fri Mar 11 2016 blino <blino> 6.3-1.mga6
+ Revision: 989141
- 6.3 (fixes Floating Point Exception when setting serial speed)

* Tue Jan 05 2016 shlomif <shlomif> 6.2-1.mga6
+ Revision: 919823
- New version 6.2

* Sun Dec 21 2014 shlomif <shlomif> 6.1-7.mga5
+ Revision: 804613
- Require systemd in post/postun - fix MGA#14513

* Wed Nov 19 2014 juergen_harms <juergen_harms> 6.1-6.mga5
+ Revision: 797821
- Changed BuildRequires: pkgconfkit(usblib) to libusb0.1-devel

* Wed Oct 15 2014 umeabot <umeabot> 6.1-5.mga5
+ Revision: 743135
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 6.1-4.mga5
+ Revision: 678078
- Mageia 5 Mass Rebuild

* Thu Jul 10 2014 juergen_harms <juergen_harms> 6.1-3.mga5
+ Revision: 651088
- recognize programmers with new firmware (or updated by Atmel Studio 6)

* Sat Jul 05 2014 pterjan <pterjan> 6.1-2.mga5
+ Revision: 643567
- Replace libusb*-devel BuildRequires by better ones

* Sun May 04 2014 shlomif <shlomif> 6.1-1.mga5
+ Revision: 619969
- Fix for build
- Add BR
- New version 6.1

* Wed Dec 11 2013 juergen_harms <juergen_harms> 6.0.1-4.mga4
+ Revision: 556374
- add udev rule for JTAGICE3 USB interface

* Thu Oct 24 2013 juergen_harms <juergen_harms> 6.0.1-3.mga4
+ Revision: 546815
- permit user acces via usb: create rules file, reload rules

* Mon Oct 21 2013 umeabot <umeabot> 6.0.1-2.mga4
+ Revision: 539986
- Mageia 4 Mass Rebuild

* Tue Oct 08 2013 juergen_harms <juergen_harms> 6.0.1-1.mga4
+ Revision: 493112
- upgrade to new upstream version = avrdude-6.0.1
- drop obsolete fix-texi-errors.patch
- re-diff avrdude-doc.patch

* Mon Aug 19 2013 fwang <fwang> 5.11.1-3.mga4
+ Revision: 467644
- update file list
- only build info now
- fix build with recent texinfo

* Fri Jan 11 2013 umeabot <umeabot> 5.11.1-3.mga3
+ Revision: 346708
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Oct 03 2012 malo <malo> 5.11.1-2.mga3
+ Revision: 302670
- BuildRequires texinfo-tex
- update RPM group

* Tue Jan 10 2012 dmorgan <dmorgan> 5.11.1-1.mga2
+ Revision: 194617
- Fix requires
+ mcb30 <mcb30>
- Upgrade to version 5.11.1
- Remove pre-Mageia cruft from specfile
- imported package avrdude


* Sat Oct 09 2010 Thomas Spuhler <tspuhler@mandriva.org> 5.10-2mdv2011.0
+ Revision: 584474
- increased rel for rebuild

* Tue Jan 19 2010 Frederik Himpe <fhimpe@mandriva.org> 5.10-1mdv2010.1
+ Revision: 493778
- update to new version 5.10

* Mon Jan 18 2010 Frederik Himpe <fhimpe@mandriva.org> 5.9-1mdv2010.1
+ Revision: 493272
- update to new version 5.9

* Wed Sep 23 2009 Frederik Himpe <fhimpe@mandriva.org> 5.8-1mdv2010.0
+ Revision: 447943
- Update to new version 5.8

* Thu Sep 10 2009 Thierry Vignaud <tv@mandriva.org> 5.5-4mdv2010.0
+ Revision: 436713
- rebuild

* Wed Mar 11 2009 Guillaume Rousse <guillomovitch@mandriva.org> 5.5-3mdv2009.1
+ Revision: 354042
- rebuild for latest readline

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 5.5-2mdv2009.0
+ Revision: 266231
- rebuild early 2009.0 package (before pixel changes)

* Sat May 03 2008 Marcelo Ricardo Leitner <mrl@mandriva.com> 5.5-1mdv2009.0
+ Revision: 200785
- Adapted to Mandriva
- import avrdude


* Wed Feb 20 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 5.5-3
- Autorebuild for GCC 4.3

* Fri Jan 11 2008 Trond Danielsen <trond.danielsen@gmail.com> - 5.5-2
- Added patch for 64-bit systems.
- Corrected the URL to the avrude homepage.

* Sat Dec 29 2007 Trond Danielsen <trond.danielsen@gmail.com> - 5.5-1
- New upstream version
- Fixed minor rpmlint warning.

* Fri Mar 02 2007 Trond Danielsen <trond.danielsen@gmail.com> - 5.3.1-5
- Added missing BuildRequire tetex-dvips.

* Thu Feb 29 2007 Trond Danielsen <trond.danielsen@gmail.com> - 5.3.1-4
- Updated list of files.
- Corrected sed line in prep section.

* Wed Feb 28 2007 Trond Danielsen <trond.danielsen@gmail.com> - 5.3.1-3
- Added missing BuildRequires.
- Enable generation of documentation.
- Updated path to avrdude.conf in info page.

* Wed Feb 28 2007 Trond Danielsen <trond.danielsen@gmail.com> - 5.3.1-2
- Added missing BuildRequires readline-devel and ncurses-devel.
- Changed config file to noreplace and moved to separate folder.
- Corrected permission for file debuginfo package.

* Wed Feb 28 2007 Trond Danielsen <trond.danielsen@gmail.com> - 5.3.1-1
- Initial version.
